#!/bin/bash
#
# freebox-tools:bin/api/freebox-port-forwarding-api.sh
#

#
# PortForwardingConfig
#
# id int - forwarding id
# enabled bool - is forwarding enabled
# ip_proto enum - "tcp" or "udp"
# wan_port_start string - forwarding range start
# wan_port_end int - forwarding range end
# lan_ip string - forwarding target on LAN
# lan_port int - forwarding target start port on LAN, (last port is lan_port + wan_port_end - wan_port_start)
# src_ip string - if src_ip == 0.0.0.0 this rule will apply to any src ip otherwise it will only apply to the specified ip address
# comment string - comment
#
# Read-only (hidden)
# hostname string - forwarding target host name
# host LanHost - forwarding target host information

function freebox_show_port_forwarding {
  local result=
  result="$( freebox_api_get '/fw/redir/' )" || return $?

  jq --sort-keys '
del( .result // [] | .[].host) |
del( .result // [] | .[].hostname) |
.result |= sort_by( .id )' <<<"${result}" || return $?
}

function freebox_show_port_forwarding_by_id {
  local -ri id="$1"

  local result=
  result="$( freebox_api_get "/fw/redir/${id}" )" || return $?

  jq --sort-keys '. | del( .result.host, .result.hostname )' <<<"${result}" || return $?
}

# PUT /api/v8/fw/redir/{redir_id}
#
# Update a PortForwardingConfig properties
function freebox_update_port_forwarding_by_id {
  local -ri id="$1"
  local -r datajson="$2"

  jq '.' <<<"${datajson}" >&2 || return $?

  local result=
  result="$( freebox_api_put "/fw/redir/${id}" "${datajson}" )" || return $?

  jq --sort-keys '.' <<<"${result}" || return $?
}
