#!/bin/bash -e
#
# freebox-tools:bin/freebox-reset-plugs.sh
#
set -u
set -o pipefail

PROJECT_HOME="$( dirname "$( dirname "$( realpath "${BASH_SOURCE[0]}" )" )" )"
declare -r PROJECT_HOME

# shellcheck disable=SC1091
source "${PROJECT_HOME}/apis/bash-common-api/bash-common-api.sh" || exit $?

declare -r FREEBOX_BIN="${PROJECT_HOME}/bin/freebox.sh"

function usage {
  cat <<EOF
Assistant pour votre Freebox redémarrer les boitiers CPL (freeplugs).

Usage:
  $( basename "${BASH_SOURCE[0]}" ) --help
  $( basename "${BASH_SOURCE[0]}" ) [--debug] [--insecure] [--allow-http]

Actions:
  -h,   --help          Affiche ce message d’aide et quitte.

Options:
  -D,   --debug         Affiche les traces

  -k,   --insecure      Autorise les connexions non certifiées lors de l’utilisation de SSL

        --http,
        --allow-http
                        Autorise l’utilisation du protocole http (non sécurisé)

EOF
}

function freebox_reset_all_plugs {
  "${FREEBOX_BIN}" --plug-reset-all || return $?
}

function main {
  local param=

  while [ "$#" -gt 0 ] ; do
    param="$1"
    shift

    case "${param}" in
      '-h'|'--help')
        usage 'true'
        return 0
        ;;

      '-k'|'--insecure')
        declare -gx FREEBOX_INSECURE='true'
        ;;

      '--http'|'--allow-http')
        declare -gx FREEBOX_HTTPS_ONLY='true'
        ;;

      '-D'|'--debug')
        declare -gx FREEBOX_DEBUG_CURL='true'
        declare -gx FREEBOX_DEBUG_CURL_OUTPUT='true'
        ;;

      *)
        # unknown option
        echofatal "Paramètre inconnu: '${param}'."
        usage >&2
        return 1
        ;;
    esac
  done

  freebox_reset_all_plugs || return $?
}

main "$@" || exit $?
